"""
Hotedit, the library for opening an editor
"""

__version__ = "0.9.0"

from hotedit.editor import (
    HoteditException,
    EditingException,
    Unchanged,
    determine_editor,
    hotedit,
)
